#
# spec file for package python-langfuse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-langfuse
Version:        2.44.0
Release:        1.1
Summary:        A client library for accessing langfuse
License:        MIT
URL:            https://github.com/langfuse/langfuse
Source:         https://files.pythonhosted.org/packages/source/l/langfuse/langfuse-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-anyio
Requires:       python-backoff
Requires:       python-httpx
Requires:       python-idna
Requires:       python-packaging
Requires:       python-pydantic
Requires:       python-wrapt
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A client library for accessing langfuse, an open-source LLM engineering platform that helps teams
collaboratively debug, analyze, and iterate on their LLM applications.

%prep
%autosetup -p1 -n langfuse-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/release
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative release

%postun
%python_uninstall_alternative release

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/release
%{python_sitelib}/langfuse
%{python_sitelib}/langfuse-%{version}.dist-info

%changelog
* Thu Oct 31 2024 Matej Cepl <mcepl@cepl.eu>
- Add missing Requires.
* Fri Sep 27 2024 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- version update to 2.44.0
  changes since v2.43.1
  - fix: rename careers file to match hackernews post (#2115)
  - fix: link of help link of eval log
  - docs: careers file extension (#2105)
  - docs: Update .env.prod.example (#2103)
  - fix(ui): parse chatml messages where content is an array (#2100)
  - fix(ui): spacing of user menu
  - fix(ui): padding of second-level menu
  - feat(ui): less padding in main menu (#2095)
  - fix(api): merge tags when upserting a trace (#2091)
  - fix: set cache control explicitly (#2088)
  - fix(cloud): remove custom cookie management (#2087)
  - chore: adjust sentry (#2086)
  - feat(cloud): include data region in project invite emails
  - feat(auth): improve auth error messages and logging
  - fix(ui): use `svh` for fullscreen pages on mobile (#2076)
  - feat(auth): capture unexpected credential sign-in errors
  - feat(cloud): data region select and info modal (#2085)
  - intercept OpenAI requests in worker testruns (#2020)
  - fix(api): align get/v2/prompts meta response with api spec (#2079)
* Wed Aug 21 2024 Aline Werner <aline.werner@suse.com>
- Fix executable file conflict for Tumbleweed build, change description and add missing URL.
* Fri Aug  9 2024 Aline Werner <aline.werner@suse.com>
- Initial package creation for python-langfuse version 2.43.1
